@@ -1,5 +1,4 @@
-export2html<-function(x, file, which.table="descr", nmax = TRUE, ...){
-
+export2html<-function(x, file, which.table="descr", nmax=TRUE, header.labels=c(), ...){
     if (!inherits(x, "createTable")) 
         stop("x must be of class 'createTable'")
     if (inherits(x, "cbind.createTable")) 
@@ -8,8 +7,8 @@ export2html<-function(x, file, which.table="descr", nmax = TRUE, ...){
     if (is.na(ww)) 
         stop(" argument 'which.table' must be either 'descr', 'avail' or 'both'")
     if (ww %in% c(1, 3)) {
-        pp <- prepare(x, nmax = nmax)
-        table1 <- prepare(x, nmax = nmax)[[1]]
+        pp <- prepare(x, nmax = nmax, header.labels)
+        table1 <- prepare(x, nmax = nmax, header.labels)[[1]]
         cc <- unlist(attr(pp, "cc"))
         ii <- ifelse(rownames(table1)[2] == "", 2, 1)
         table1 <- cbind(rownames(table1), table1)
@@ -18,8 +17,7 @@ export2html<-function(x, file, which.table="descr", nmax = TRUE, ...){
         aux <- NULL
         for (i in (ii + 1):nrow(table1)) {
             if (!is.null(cc) && cc[i - ii] != "") {
-                aux <- rbind(aux, c(cc[i - ii], rep("", ncol(table1) - 
-                  1)))
+                aux <- rbind(aux, c(cc[i - ii], rep("", ncol(table1) - 1)))
                 aux <- rbind(aux, table1[i, ])
             }
             else {
@@ -27,13 +25,11 @@ export2html<-function(x, file, which.table="descr", nmax = TRUE, ...){
             }
         }
         table1 <- rbind(table1[1:ii, ], aux)
-        table1[, 1] <- sub("^    ", "&nbsp;&nbsp;&nbsp;&nbsp;", 
-            table1[, 1])
-        if (nrow(table1) > 1 && length(grep("^N=", trim(table1[2, 
-            2])))) {
+        table1[, 1] <- sub("^    ", "&nbsp;&nbsp;&nbsp;&nbsp;", table1[, 1])
+        table1[, 1] <- sub("^\\&nbsp;\\&nbsp;\\&nbsp;\\&nbsp;    ", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;", table1[, 1])        
+        if (nrow(table1) > 1 && length(grep("^N=", trim(table1[2, 2])))) {
             wn <- grep("^N=", trim(table1[2, ]))
-            nn <- paste(trim(table1[1, wn]), "<br/>", trim(table1[2, 
-                wn]))
+            nn <- paste(trim(table1[1, wn]), "<br/>", trim(table1[2, wn]))
             table1[1, wn] <- nn
             table1 <- table1[-2, ]
         }
@@ -41,19 +37,19 @@ export2html<-function(x, file, which.table="descr", nmax = TRUE, ...){
         table1[1, 1] <- "Var"
         colnames(table1) <- table1[1, ]
         table1 <- table1[-1, ,drop=FALSE]
-        print(xtable(table1, align = align), type = "html", file = paste(file, 
-            ".html", sep = ""), include.rownames = FALSE, sanitize.text.function = function(x) x)
+        print(xtable(table1, align = align), type = "html", file = file, 
+            include.rownames = FALSE, sanitize.text.function = function(x) x)
     }
     if (ww %in% c(2, 3)) {
-        table2 <- prepare(x, nmax = nmax)[[2]]
+        table2 <- prepare(x, nmax = nmax, c())[[2]]
         table2 <- cbind(rownames(table2), table2)
-        if (!is.null(attr(x, "caption"))) {
+          if (!is.null(attr(x, "caption"))) {
             cc <- unlist(attr(x, "caption"))
             table2[, 1] <- paste("    ", table2[, 1])
         }
         aux <- NULL
         for (i in 2:nrow(table2)) {
-            if (!is.null(cc) && cc[i - 1] != "") {
+            if (!is.null(attr(x, "caption")) && !is.null(cc) && cc[i - 1] != "") {
                 aux <- rbind(aux, c(cc[i - 1], rep("", ncol(table2) - 
                   1)))
                 aux <- rbind(aux, table2[i, ])
@@ -63,12 +59,14 @@ export2html<-function(x, file, which.table="descr", nmax = TRUE, ...){
             }
         }
         table2 <- rbind(table2[1, ], aux)
+        table2[, 1] <- sub("^    ", "&nbsp;&nbsp;&nbsp;&nbsp;", table2[, 1])
+        table2[, 1] <- sub("^\\&nbsp;\\&nbsp;\\&nbsp;\\&nbsp;    ", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;", table2[, 1])
         table2[1, 1] <- "Var"
         align <- c("l", "l", rep("c", ncol(table2) - 1))
         colnames(table2) <- table2[1, ]
         table2 <- table2[-1, ,drop=FALSE]
-        print(xtable(table2, align = align), type = "html", file = paste(file, 
-            "_appendix.html", sep = ""), include.rownames = FALSE, 
-            sanitize.text.function = function(x) x)
+        file.save<-paste(sub("\\.html$","",file),"_appendix.html",sep="")
+        print(xtable(table2, align = align), type = "html", file = file.save, 
+            include.rownames = FALSE, sanitize.text.function = function(x) x)
     }
 }
