@@ -1,33 +1,51 @@
 # Read contextual help file 
 
-shinyUI(pageWithSidebar(
+shinyUI(fluidPage(
     
     #headerPanel(HTML('<h2>compareGroups: descriptive statistics by goups</h2>')),   
     headerPanel("",windowTitle="compareGroups | Explore and Summarise Epidemiological Data in R"),
-    sidebarPanel(   
-  
-      tags$head(
-        tags$link(rel = "stylesheet", type = "text/css", href = "bootstrap.css"),
-        tags$style(HTML("@import url('//fonts.googleapis.com/css?family=Lobster|Cabin:400,700');")),
-        tags$style(HTML(".span4{width: 27%; scroll:auto;};")),
-        tags$style(HTML(".span4 .well{background-color:#E0E0E0; border:1px solid grey}")),
-        tags$style(type = "text/css", ".navbar {background-color: blue;}")
-      ),
+
+    HTML('<style type="text/css"> #inputpanel{ background-color: rgb(200,200,200); border: 2px solid grey; box-shadow: 2px 2px 1px #888888; } </style>'),
+    HTML('<style type="text/css"> #inputpanel .well{ background-color: rgb(200,200,200); border: 2px solid grey;} </style>'),
+    HTML('<style type="text/css"> #outpanel { background-color: rgb(250,250,250); border: 2px solid grey; box-shadow: 2px 2px 1px #888888;} </style>'),
+    HTML('<style type="text/css"> #showload { background-color: rgb(250,250,250); border: 2px solid grey;} </style>'),
+    HTML('<style type="text/css"> #selevars { width: 120px;} </style>'), 
+    HTML('<style type="text/css"> #discvars { width: 120px;} </style>'),
+    HTML('<style type="text/css"> #changeselevars { font-size: 15px; border: 2px solid grey;} </style>'),
+    HTML('<style type="text/css"> #varPlot { width: 120px;} </style>'),
+    HTML('<style type="text/css"> #maxvalues { width: 100px;} </style>'),
+     
 
 
-           # tags$head(
-           #     tags$style("body {background-color: lightgreen; }")
-           # ),
-           
+#    tags$head(
+#      tags$link(rel = "stylesheet", type = "text/css", href = "bootstrap.css"),
+#      tags$style(HTML("@import url('//fonts.googleapis.com/css?family=Lobster|Cabin:400,700');")),
+#      tags$style(HTML(".span4{width: 27%; scroll:auto;};")),
+#      tags$style(HTML(".span4 .well{background-color:#E0E0E0; border:1px solid grey}")),
+#      tags$style(type = "text/css", ".navbar {background-color: blue;}")
+#    ),
 
+
+    fluidRow(
+
+    ##################################################     
+    ################ CONTROL PANEL ###################
+    ##################################################
+    
+    column(4,
+
+      wellPanel(id="inputpanel",   
+      
       tabsetPanel(id="menu", type="pills",
         #### Loads data and lists variables in the data set to be selected####
         tabPanel("START",
           ## load
           div(class="row-fluid",
-            div(class="span6",HTML("<button id='showload' type='button' class='btn action-button' style='border:2px solid grey'><b>Toggle Load Panel</b></button>")),
-            div(class="span5 offset0",uiOutput("initial")),
             wellPanel(
+              fluidRow(
+                column(6,HTML("<button id='showload' type='button' class='btn action-button' style='border:2px solid grey'><b>Toggle Load Panel</b></button>")),
+                column(6,uiOutput("initial"))
+              ),
               conditionalPanel(
                 condition = "input.showload != null && input.showload % 2 == 0",
                 div(  
@@ -58,14 +76,17 @@ shinyUI(pageWithSidebar(
           ),
           ## response
           tabPanel("Response",
+            hr(),
             radioButtons('resptype', 'Response type',  c("None","Group","Survival"),'None'),                 
             uiOutput("response")
           ),            
           ## hide
           tabPanel("Hide",
             wellPanel(
-              uiOutput("selehidevar"),
-              uiOutput("selehidecat")
+              fluidRow(
+                column(6,uiOutput("selehidevar")),
+                column(6,uiOutput("selehidecat"))
+              )
             ),
             textInput('hideno', "Hide 'no' category", '')
           ),
@@ -100,13 +121,14 @@ shinyUI(pageWithSidebar(
           uiOutput("save")
         )
       )
-    ),
+    )),
+    
+    #################################
+    #######  RESULTS PANEL ##########
+    #################################
 
-    ###########################
-    #######  RESULTS ##########
-    ###########################
-
-    mainPanel(
+    column(8,
+      wellPanel(id="outpanel",
     
           tabsetPanel(id="results",type="pills",selected="TABLE",
                       tabPanel("INFO",
@@ -119,7 +141,8 @@ shinyUI(pageWithSidebar(
                         ),
                         # extended
                         tabPanel("Extended",
-                          dataTableOutput('valuesext')
+                          sliderInput("valueextsize", "Resize (%):", min=10, max=300, value=100, step=10),
+                          uiOutput("valuesext")
                         )
                       ),                      
                       tabPanel("TABLE",
@@ -146,7 +169,7 @@ shinyUI(pageWithSidebar(
                         )
                       )                      
           )
-    )
-)
+    ))
+  )
 
-)                               
+))                               
